pub struct StatusReason<'a>(/* private fields */);Expand description
A wrapper around a status reason that offers additional detail.
This is the return type of StackEventDetails::resource_status_reason. The detail
method will attempt to parse the inner status reason into StatusReasonDetail, which can
indicate what specifically went wrong. The underlying status reason can be retrieved via
inner.
Implementations
Sourceimpl<'a> StatusReason<'a>
impl<'a> StatusReason<'a>
Sourcepub fn inner(&self) -> Option<&'a str>
pub fn inner(&self) -> Option<&'a str>
The raw status reason, in case you need to work with it directly.
Sourcepub fn detail(&self) -> Option<StatusReasonDetail<'a>>
pub fn detail(&self) -> Option<StatusReasonDetail<'a>>
Additional detail about the status reason, if available.
This currently depends on some preset parsing of the status reason string for various common
error reasons. See StatusReasonDetail for current possibilities.