pub struct StackWarning {
    pub stack_id: String,
    pub resource_events: Vec<(ResourceStatus, StackEventDetails)>,
}
Describes a successful stack operation with warnings.

It is possible for resource errors to occur even when the overall operation succeeds, such as failing to delete a resource during clean-up after a successful update. Rather than letting this pass silently, or relying on carefully interrogating StackEvents, the operation returns an error.

Fields

stack_id: String

The ID of the stack.

resource_events: Vec<(ResourceStatus, StackEventDetails)>

Resource events with negative statuses that did not affect the overall operation.

Note: this is represented as a Vec of tuples to avoid having to worry about matching StackEvent variants (when it would be a logical error for them to be anything other than the Resource variant).